===============
Release history
===============

1.3.0
-----

- Automatically remove 'Sent from my iPhone' line from end of habit list backup
  emails before importing


1.2.0
-----

- Added support for sleep cycle csv data

1.1.0
-----

- Added support for pedometerpp service
    - Thanks [jotefa](https://github.com/jotefa)
